-- FILE : DE-1608.B  v 1.02.00.b


-- MIB file of DE-1608 Ver 1.02.00



-- This file includes three private mibs
--     RFC-1368
--     D-Link common mib
--     DE-1608 BackBone mib ( v 1.02.00)


DE-1608-MIB DEFINITIONS ::= BEGIN


IMPORTS

     enterprises, NetworkAddress, IpAddress,
     Counter, Gauge, TimeTicks           FROM RFC1155-SMI
     DisplayString                       FROM RFC1213-MIB
     TRAP-TYPE                           FROM RFC-1215
     OBJECT-TYPE                         FROM RFC-1212;

MacAddress ::= OCTET STRING( SIZE(6))


mib-2           OBJECT IDENTIFIER ::=  {mgmt 1}
snmpDot3RptrMgt OBJECT IDENTIFIER ::=  { mib-2 22 }


dlink      OBJECT IDENTIFIER ::= { enterprises 171 }

common     OBJECT IDENTIFIER ::= { dlink 3 }

secondGenRptrMIB OBJECT IDENTIFIER ::= { dlink           7}

device     OBJECT IDENTIFIER ::= { common 1 }
management OBJECT IDENTIFIER ::= { common 2 }
action     OBJECT IDENTIFIER ::= { common 3 }

de1608MIB        OBJECT IDENTIFIER ::= { secondGenRptrMIB 2}
ver-One          OBJECT IDENTIFIER ::= { de1608MIB        1}




--
--   SNMP-REPEATER-MIB DEFINITIONS
--

   -- All representations of MAC addresses in this MIB Module use,
   -- as a textual convention (i.e., this convention does not affect
   -- their encoding), the data type:

   -- defined by IEEE 802.1a, i.e., as if it were transmitted least
   -- significant bit first.
   --                      References
   --
   -- The following references are used throughout this MIB:
   --
   -- [IEEE 802.3 Std]
   --    refers to IEEE 802.3/ISO 8802-3 Information processing
   --    systems - Local area networks - Part 3: Carrier sense
   --    multiple access with collision detection (CSMA/CD)
   --    access method and physical layer specifications
   --    (2nd edition, September 21, 1990).
   --
   -- [IEEE 802.3 Rptr Mgt]
   --    refers to IEEE P802.3K, 'Layer Management for 10 Mb/s
   --    Baseband Repeaters, Section 19,' Draft Supplement to
   --    ANSI/IEEE 802.3, (Draft 8, April 9, 1992)


   --                      MIB Groups
   --
   -- The rptrBasicPackage group is mandatory.
   -- The rptrMonitorPackage and rptrAddrTrackPackage
   -- groups are optional.


   rptrBasicPackage
       OBJECT IDENTIFIER ::= { snmpDot3RptrMgt 1 }

   rptrMonitorPackage
       OBJECT IDENTIFIER ::= { snmpDot3RptrMgt 2 }

   rptrAddrTrackPackage
       OBJECT IDENTIFIER ::= { snmpDot3RptrMgt 3 }


   -- object identifiers for organizing the information
   -- in the groups by repeater, port-group, and port

   rptrRptrInfo
       OBJECT IDENTIFIER ::= { rptrBasicPackage 1 }
   rptrGroupInfo
       OBJECT IDENTIFIER ::= { rptrBasicPackage 2 }
   rptrPortInfo
       OBJECT IDENTIFIER ::= { rptrBasicPackage 3 }

   rptrMonitorRptrInfo
       OBJECT IDENTIFIER ::= { rptrMonitorPackage 1 }
   rptrMonitorGroupInfo
       OBJECT IDENTIFIER ::= { rptrMonitorPackage 2 }
   rptrMonitorPortInfo
       OBJECT IDENTIFIER ::= { rptrMonitorPackage 3 }

   rptrAddrTrackRptrInfo     -- this subtree is currently unused
       OBJECT IDENTIFIER ::= { rptrAddrTrackPackage 1 }
   rptrAddrTrackGroupInfo    -- this subtree is currently unused
       OBJECT IDENTIFIER ::= { rptrAddrTrackPackage 2 }
   rptrAddrTrackPortInfo
       OBJECT IDENTIFIER ::= { rptrAddrTrackPackage 3 }

   --
   --                    The BASIC GROUP
   --
   -- Implementation of the Basic Group is mandatory for all
   -- managed repeaters.

   --
   -- Basic Repeater Information
   --
   -- Configuration, status, and control objects for the overall
   -- repeater
   --

   rptrGroupCapacity OBJECT-TYPE
       SYNTAX    INTEGER (1..1024)
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
                      "The rptrGroupCapacity is the number of groups
                      that can be contained within the repeater.  Within
                      each managed repeater, the groups are uniquely
                      numbered in the range from 1 to rptrGroupCapacity.

                      Some groups may not be present in the repeater, in
                      which case the actual number of groups present
                      will be less than rptrGroupCapacity.  The number
                      of groups present will never be greater than
                      rptrGroupCapacity.

                      Note:  In practice, this will generally be the
                      number of field-replaceable units (i.e., modules,
                      cards, or boards) that can fit in the physical
                      repeater enclosure, and the group numbers will
                      correspond to numbers marked on the physical
                      enclosure."
   REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.3.2,
               aRepeaterGroupCapacity."
   ::= { rptrRptrInfo 1 }

   rptrOperStatus OBJECT-TYPE
       SYNTAX  INTEGER {
                   other(1),            -- undefined or unknown status
                   ok(2),               -- no known failures
                   rptrFailure(3),      -- repeater-related failure
                   groupFailure(4),     -- group-related failure
                   portFailure(5),      -- port-related failure
                   generalFailure(6)    -- failure, unspecified type
               }
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
              "The rptrOperStatus object indicates the
              operational state of the repeater.  The
              rptrHealthText object may be consulted for more
              specific information about the state of the
              repeater's health.

              In the case of multiple kinds of failures (e.g.,
              repeater failure and port failure), the value of
              this attribute shall reflect the highest priority
              failure in the following order:

                   rptrFailure(3)
                   groupFailure(4)
                   portFailure(5)
                   generalFailure(6)."
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.3.2,
               aRepeaterHealthState."
       ::= { rptrRptrInfo 2 }

   rptrHealthText OBJECT-TYPE
       SYNTAX    DisplayString (SIZE (0..255))
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "The health text object is a text string that
               provides information relevant to the operational
               state of the repeater. Agents may use this string
               to provide detailed information on current
               failures, including how they were detected, and/or
               instructions for problem resolution. The contents
               are agent-specific."
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.3.2,
               aRepeaterHealthText."
       ::= { rptrRptrInfo 3 }

   rptrReset OBJECT-TYPE
       SYNTAX    INTEGER {
                     noReset(1),
                     reset(2)
                 }
       ACCESS    read-write
       STATUS    mandatory
       DESCRIPTION
               "Setting this object to reset(2) causes a
               transition to the START state of Fig 9-2 in
               section 9 [IEEE 802.3 Std].

               Setting this object to noReset(1) has no effect.
               The agent will always return the value noReset(1)
               when this object is read.

               This action does not reset the management counters
               defined in this document nor does it affect the
               portAdminStatus parameters.  Included in this
               action is the execution of a disruptive Self-Test
               with the following characteristics:  a) The nature
               of the tests is not specified.  b) The test resets
               the repeater but without affecting management
               information about the repeater.  c) The test does
               not inject packets onto any segment.  d) Packets
               received during the test may or may not be
               transferred.  e) The test does not interfere with
               management functions.

               As a result of this action a rptrResetEvent trap
               should be sent."
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.3.3,
               acResetRepeater."
       ::= { rptrRptrInfo 4 }

   rptrNonDisruptTest OBJECT-TYPE
       SYNTAX    INTEGER {
                     noSelfTest(1),
                     selfTest(2)
                 }
       ACCESS    read-write
       STATUS    mandatory
       DESCRIPTION
               "Setting this object to selfTest(2) causes the
               repeater to perform a agent-specific, non-
               disruptive self-test that has the following
               characteristics:  a) The nature of the tests is
               not specified.  b) The test does not change the
               state of the repeater or management information
               about the repeater.  c) The test does not inject
               packets onto any segment.  d) The test does not
               prevent the relay of any packets.  e) The test
               does not interfere with management functions.

               After performing this test the agent will update
               the repeater health information and send a
               rptrHealth trap.

               Setting this object to noSelfTest(1) has no
               effect.  The agent will always return the value
               noSelfTest(1) when this object is read."
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.3.3,
               acExecuteNonDisruptiveSelfTest."
       ::= { rptrRptrInfo 5 }

   rptrTotalPartitionedPorts OBJECT-TYPE
       SYNTAX    Gauge
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "This object returns the total number of ports in
               the repeater whose current state meets all three
               of the following criteria:  rptrPortOperStatus
               does not have the value notPresent(3),
               rptrPortAdminStatus is enabled(1), and
               rptrPortAutoPartitionState is autoPartitioned(2)."
       ::= { rptrRptrInfo 6 }


   --
   -- The Basic Port Group Table
   --

   rptrGroupTable OBJECT-TYPE
       SYNTAX    SEQUENCE OF RptrGroupEntry
       ACCESS    not-accessible
       STATUS    mandatory
       DESCRIPTION
               "Table of descriptive and status information about
               the groups of ports."
       ::= { rptrGroupInfo 1 }

   rptrGroupEntry OBJECT-TYPE
       SYNTAX    RptrGroupEntry
       ACCESS    not-accessible
       STATUS    mandatory
       DESCRIPTION
               "An entry in the table, containing information
               about a single group of ports."
       INDEX    { rptrGroupIndex }
       ::= { rptrGroupTable 1 }

   RptrGroupEntry ::=
       SEQUENCE {
           rptrGroupIndex
               INTEGER,
           rptrGroupDescr
               DisplayString,
           rptrGroupObjectID
               OBJECT IDENTIFIER,
           rptrGroupOperStatus
               INTEGER,
           rptrGroupLastOperStatusChange
               TimeTicks,
           rptrGroupPortCapacity
               INTEGER
       }

   rptrGroupIndex OBJECT-TYPE
       SYNTAX    INTEGER (1..1024)
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "This object identifies the group within the
               repeater for which this entry contains
               information.  This value is never greater than
               rptrGroupCapacity."
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.5.2,
               aGroupID."
       ::= { rptrGroupEntry 1 }

   rptrGroupDescr OBJECT-TYPE
       SYNTAX    DisplayString (SIZE (0..255))
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "A textual description of the group.  This value
               should include the full name and version
               identification of the group's hardware type and
               indicate how the group is differentiated from
               other groups in the repeater.  Plug-in Module, Rev
               A' or 'Barney Rubble 10BASE-T 4-port SIMM socket
               Version 2.1' are examples of valid group
               descriptions.

               It is mandatory that this only contain printable
               ASCII characters."
       ::= { rptrGroupEntry 2 }

   rptrGroupObjectID OBJECT-TYPE
       SYNTAX    OBJECT IDENTIFIER
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "The vendor's authoritative identification of the
               group.  This value is allocated within the SMI
               enterprises subtree (1.3.6.1.4.1) and provides a
               straight-forward and unambiguous means for
               determining what kind of group is being managed.

               For example, this object could take the value
               1.3.6.1.4.1.4242.1.2.14 if vendor 'Flintstones,
               Inc.' was assigned the subtree 1.3.6.1.4.1.4242,
               and had assigned the identifier
               1.3.6.1.4.1.4242.1.2.14 to its 'Wilma Flintstone
               6-Port FOIRL Plug-in Module.'"
       ::= { rptrGroupEntry 3 }

   rptrGroupOperStatus OBJECT-TYPE
       SYNTAX    INTEGER {
                     other(1),
                     operational(2),
                     malfunctioning(3),
                     notPresent(4),
                     underTest(5),
                     resetInProgress(6)
                 }
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "An object that indicates the operational status
               of the group.

               A status of notPresent(4) indicates that the group
               is temporarily or permanently physically and/or
               logically not a part of the repeater.  It is an
               implementation-specific matter as to whether the
               agent effectively removes notPresent entries from
               the table.

               A status of operational(2) indicates that the
               group is functioning, and a status of
               malfunctioning(3) indicates that the group is
               malfunctioning in some way."
       ::= { rptrGroupEntry 4 }

   rptrGroupLastOperStatusChange OBJECT-TYPE
       SYNTAX    TimeTicks
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "An object that contains the value of sysUpTime at
               the time that the value of the rptrGroupOperStatus
               object for this group last changed.

               A value of zero indicates that the group's oper
               status has not changed since the agent last
               restarted."
       ::= { rptrGroupEntry 5 }

   rptrGroupPortCapacity OBJECT-TYPE
       SYNTAX    INTEGER (1..1024)
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "The rptrGroupPortCapacity is the number of ports
               that can be contained within the group.  Valid
               range is 1-1024.  Within each group, the ports are
               uniquely numbered in the range from 1 to
               rptrGroupPortCapacity.

               Note:  In practice, this will generally be the
               number of ports on a module, card, or board, and
               the port numbers will correspond to numbers marked
               on the physical embodiment."
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.5.2,
               aGroupPortCapacity."
       ::= { rptrGroupEntry 6 }



   --
   -- The Basic Port Table
   --

   rptrPortTable OBJECT-TYPE
       SYNTAX    SEQUENCE OF RptrPortEntry
       ACCESS    not-accessible
       STATUS    mandatory
       DESCRIPTION
               "Table of descriptive and status information about
               the ports."
       ::= { rptrPortInfo 1 }

   rptrPortEntry OBJECT-TYPE
       SYNTAX    RptrPortEntry
       ACCESS    not-accessible
       STATUS    mandatory
       DESCRIPTION
               "An entry in the table, containing information
               about a single port."
       INDEX    { rptrPortGroupIndex, rptrPortIndex }
       ::= { rptrPortTable 1 }

   RptrPortEntry ::=
       SEQUENCE {
           rptrPortGroupIndex
               INTEGER,
           rptrPortIndex
               INTEGER,
           rptrPortAdminStatus
               INTEGER,
           rptrPortAutoPartitionState
               INTEGER,
           rptrPortOperStatus
               INTEGER
       }

   rptrPortGroupIndex OBJECT-TYPE
       SYNTAX    INTEGER (1..1024)
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "This object identifies the group containing the
               port for which this entry contains information."
       ::= { rptrPortEntry 1 }

   rptrPortIndex OBJECT-TYPE
       SYNTAX    INTEGER (1..1024)
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "This object identifies the port within the group
               for which this entry contains information.  This
               value can never be greater than
               rptrGroupPortCapacity for the associated group."
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.6.2,
               aPortID."
       ::= { rptrPortEntry 2 }

   rptrPortAdminStatus OBJECT-TYPE
       SYNTAX    INTEGER {
                     enabled(1),
                     disabled(2)
                 }
       ACCESS    read-write
       STATUS    mandatory
       DESCRIPTION
               "Setting this object to disabled(2) disables the
               port.  A disabled port neither transmits nor
               receives.  Once disabled, a port must be
               explicitly enabled to restore operation.  A port
               which is disabled when power is lost or when a
               reset is exerted shall remain disabled when normal
               operation resumes.

               The admin status takes precedence over auto-
               partition and functionally operates between the
               auto-partition mechanism and the AUI/PMA.

               Setting this object to enabled(1) enables the port
               and exerts a BEGIN on the port's auto-partition
               state machine.
               (In effect, when a port is disabled, the value of
               rptrPortAutoPartitionState for that port is frozen
               until the port is next enabled.  When the port
               becomes enabled, the rptrPortAutoPartitionState
               becomes notAutoPartitioned(1), regardless of its
               pre-disabling state.)"
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.6.2,
               aPortAdminState and 19.2.6.3, acPortAdminControl."
       ::= { rptrPortEntry 3 }

   rptrPortAutoPartitionState OBJECT-TYPE
       SYNTAX    INTEGER {
                     notAutoPartitioned(1),
                     autoPartitioned(2)
                 }
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "The autoPartitionState flag indicates whether the
               port is currently partitioned by the repeater's
               auto-partition protection.

               The conditions that cause port partitioning are
               specified in partition state machine in Section 9
               [IEEE 802.3 Std].  They are not differentiated
               here."
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.6.2,
               aAutoPartitionState."
       ::= { rptrPortEntry 4 }

   rptrPortOperStatus  OBJECT-TYPE
       SYNTAX    INTEGER {
                     operational(1),
                     notOperational(2),
                     notPresent(3)
                 }
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "This object indicates the port's operational
               status.  The notPresent(3) status indicates the
               port is physically removed (note this may or may
               not be possible depending on the type of port.)

               The operational(1) status indicates that the port
               is enabled (see rptrPortAdminStatus) and working,
               even though it might be auto-partitioned (see
               rptrPortAutoPartitionState).

               If this object has the value operational(1) and
               rptrPortAdminStatus is set to disabled(2), it is
               expected that this object's value will change to
               notOperational(2) soon after."
       ::= { rptrPortEntry 5 }


   --
   --                    The MONITOR GROUP
   --
   -- Implementation of this group is optional, but within the
   -- group all elements are mandatory.  If a managed repeater
   -- implements any part of this group, the entire group shall
   -- be implemented.

   --
   -- Repeater Monitor Information
   --
   -- Performance monitoring statistics for the repeater
   --

   rptrMonitorTransmitCollisions OBJECT-TYPE
       SYNTAX    Counter
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "This counter is incremented every time the
               repeater state machine enters the TRANSMIT
               COLLISION state from any state other than ONE PORT
               LEFT (Ref: Fig 9-2, IEEE 802.3 Std).

               The approximate minimum time for rollover of this
               counter is 16 hours."
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.3.2,
               aTransmitCollisions."
       ::= { rptrMonitorRptrInfo 1 }


   --
   -- The Group Monitor Table
   --

   rptrMonitorGroupTable OBJECT-TYPE
       SYNTAX    SEQUENCE OF RptrMonitorGroupEntry
       ACCESS    not-accessible
       STATUS    mandatory
       DESCRIPTION
               "Table of performance and error statistics for the
               groups."
       ::= { rptrMonitorGroupInfo 1 }


   rptrMonitorGroupEntry OBJECT-TYPE
       SYNTAX    RptrMonitorGroupEntry
       ACCESS    not-accessible
       STATUS    mandatory
       DESCRIPTION
               "An entry in the table, containing total
               performance and error statistics for a single
               group.  Regular retrieval of the information in
               this table provides a means of tracking the
               performance and health of the networked devices
               attached to this group's ports.

               The counters in this table are redundant in the
               sense that they are the summations of information
               already available through other objects.  However,
               these sums provide a considerable optimization of
               network management traffic over the otherwise
               necessary retrieval of the individual counters
               included in each sum."
       INDEX    { rptrMonitorGroupIndex }
       ::= { rptrMonitorGroupTable 1 }

   RptrMonitorGroupEntry ::=
       SEQUENCE {
           rptrMonitorGroupIndex
               INTEGER,
           rptrMonitorGroupTotalFrames
               Counter,
           rptrMonitorGroupTotalOctets
               Counter,
           rptrMonitorGroupTotalErrors
               Counter
       }

   rptrMonitorGroupIndex OBJECT-TYPE
       SYNTAX    INTEGER (1..1024)
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "This object identifies the group within the
               repeater for which this entry contains
               information."
       ::= { rptrMonitorGroupEntry 1 }

   rptrMonitorGroupTotalFrames OBJECT-TYPE
       SYNTAX    Counter
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "The total number of frames of valid frame length
               that have been received on the ports in this
               group.  This counter is the summation of the
               values of the rptrMonitorPortReadableFrames
               counters for all of the ports in the group.

               This statistic provides one of the parameters
               necessary for obtaining the packet error rate.
               The approximate minimum time for rollover of this
               counter is 80 hours."
       ::= { rptrMonitorGroupEntry 2 }

   rptrMonitorGroupTotalOctets OBJECT-TYPE
       SYNTAX    Counter
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "The total number of octets contained in the valid
               frames that have been received on the ports in
               this group.  This counter is the summation of the
               values of the rptrMonitorPortReadableOctets
               counters for all of the ports in the group.

               This statistic provides an indicator of the total
               data transferred.  The approximate minimum time
               for rollover of this counter is 58 minutes."
       ::= { rptrMonitorGroupEntry 3 }

   rptrMonitorGroupTotalErrors OBJECT-TYPE
       SYNTAX    Counter
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "The total number of errors which have occurred on
               all of the ports in this group.  This counter is
               the summation of the values of the
               rptrMonitorPortTotalErrors counters for all of the
               ports in the group."
       ::= { rptrMonitorGroupEntry 4 }


   --
   -- The Port Monitor Table
   --

   rptrMonitorPortTable OBJECT-TYPE
       SYNTAX    SEQUENCE OF RptrMonitorPortEntry
       ACCESS    not-accessible
       STATUS    mandatory
       DESCRIPTION
               "Table of performance and error statistics for the
               ports."
       ::= { rptrMonitorPortInfo 1 }

   rptrMonitorPortEntry OBJECT-TYPE
       SYNTAX    RptrMonitorPortEntry
       ACCESS    not-accessible
       STATUS    mandatory
       DESCRIPTION
               "An entry in the table, containing performance and
               error statistics for a single port."
       INDEX    { rptrMonitorPortGroupIndex, rptrMonitorPortIndex }
       ::= { rptrMonitorPortTable 1 }

   RptrMonitorPortEntry ::=
       SEQUENCE {
           rptrMonitorPortGroupIndex
               INTEGER,
           rptrMonitorPortIndex
               INTEGER,
           rptrMonitorPortReadableFrames
               Counter,
           rptrMonitorPortReadableOctets
               Counter,
           rptrMonitorPortFCSErrors
               Counter,
           rptrMonitorPortAlignmentErrors
               Counter,
           rptrMonitorPortFrameTooLongs
               Counter,
           rptrMonitorPortShortEvents
               Counter,
           rptrMonitorPortRunts
               Counter,
           rptrMonitorPortCollisions
               Counter,
           rptrMonitorPortLateEvents
               Counter,
           rptrMonitorPortVeryLongEvents
               Counter,
           rptrMonitorPortDataRateMismatches
               Counter,
           rptrMonitorPortAutoPartitions
               Counter,
           rptrMonitorPortTotalErrors
               Counter
       }


   rptrMonitorPortGroupIndex OBJECT-TYPE
       SYNTAX    INTEGER (1..1024)
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "This object identifies the group containing the
               port for which this entry contains information."
       ::= { rptrMonitorPortEntry 1 }

   rptrMonitorPortIndex OBJECT-TYPE
       SYNTAX    INTEGER (1..1024)
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "This object identifies the port within the group
               for which this entry contains information."
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.6.2,
               aPortID."
       ::= { rptrMonitorPortEntry 2 }

   rptrMonitorPortReadableFrames OBJECT-TYPE
       SYNTAX    Counter
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "This object is the number of frames of valid
               frame length that have been received on this port.
               This counter is incremented by one for each frame
               received on this port whose OctetCount is greater
               than or equal to minFrameSize and less than or
               equal to maxFrameSize (Ref: IEEE 802.3 Std,
               4.4.2.1) and for which the FCSError and
               CollisionEvent signals are not asserted.

               This statistic provides one of the parameters
               necessary for obtaining the packet error rate.
               The approximate minimum time for rollover of this
               counter is 80 hours."
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.6.2,
               aReadableFrames."
       ::= { rptrMonitorPortEntry 3 }

   rptrMonitorPortReadableOctets OBJECT-TYPE
       SYNTAX    Counter
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "This object is the number of octets contained in
               valid frames that have been received on this port.
               This counter is incremented by OctetCount for each
               frame received on this port which has been
               determined to be a readable frame.

               This statistic provides an indicator of the total
               data transferred.  The approximate minimum time
               for rollover of this counter is 58 minutes."
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.6.2,
               aReadableOctets."
       ::= { rptrMonitorPortEntry 4 }

   rptrMonitorPortFCSErrors OBJECT-TYPE
       SYNTAX    Counter
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "This counter is incremented by one for each frame
               received on this port with the FCSError signal
               asserted and the FramingError and CollisionEvent
               signals deasserted and whose OctetCount is greater
               than or equal to minFrameSize and less than or
               equal to maxFrameSize (Ref: 4.4.2.1, IEEE 802.3
               Std).

               The approximate minimum time for rollover of this
               counter is 80 hours."
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.6.2,
               aFrameCheckSequenceErrors."
       ::= { rptrMonitorPortEntry 5 }

   rptrMonitorPortAlignmentErrors OBJECT-TYPE
       SYNTAX    Counter
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "This counter is incremented by one for each frame
               received on this port with the FCSError and
               FramingError signals asserted and CollisionEvent
               signal deasserted and whose OctetCount is greater
               than or equal to minFrameSize and less than or
               equal to maxFrameSize (Ref: IEEE 802.3 Std,
               4.4.2.1).  If rptrMonitorPortAlignmentErrors is
               incremented then the rptrMonitorPortFCSErrors
               Counter shall not be incremented for the same
               frame.

               The approximate minimum time for rollover of this
               counter is 80 hours."
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.6.2,
               aAlignmentErrors."
       ::= { rptrMonitorPortEntry 6 }

   rptrMonitorPortFrameTooLongs OBJECT-TYPE
       SYNTAX    Counter
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "This counter is incremented by one for each frame
               received on this port whose OctetCount is greater
               than maxFrameSize (Ref: 4.4.2.1, IEEE 802.3 Std).
               If rptrMonitorPortFrameTooLongs is incremented
               then neither the rptrMonitorPortAlignmentErrors
               nor the rptrMonitorPortFCSErrors counter shall be
               incremented for the frame.

               The approximate minimum time for rollover of this
               counter is 61 days."
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.6.2,
               aFramesTooLong."
       ::= { rptrMonitorPortEntry 7 }

   rptrMonitorPortShortEvents OBJECT-TYPE
       SYNTAX    Counter
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "This counter is incremented by one for each
               CarrierEvent on this port with ActivityDuration
               less than ShortEventMaxTime.  ShortEventMaxTime is
               greater than 74 bit times and less than 82 bit
               times.  ShortEventMaxTime has tolerances included
               to provide for circuit losses between a
               conformance test point at the AUI and the
               measurement point within the state machine.

               Note:  shortEvents may indicate externally
               generated noise hits which will cause the repeater
               to transmit Runts to its other ports, or propagate
               a collision (which may be late) back to the
               transmitting DTE and damaged frames to the rest of
               the network.

               Implementors may wish to consider selecting the
               ShortEventMaxTime towards the lower end of the
               allowed tolerance range to accommodate bit losses
               suffered through physical channel devices not
               budgeted for within this standard.

               The approximate minimum time for rollover of this
               counter is 16 hours."
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.6.2,
               aShortEvents."
       ::= { rptrMonitorPortEntry 8 }

   rptrMonitorPortRunts OBJECT-TYPE
       SYNTAX    Counter
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "This counter is incremented by one for each
               CarrierEvent on this port that meets one of the
               following two conditions.  Only one test need be
               made.  a) The ActivityDuration is greater than
               ShortEventMaxTime and less than ValidPacketMinTime
               and the CollisionEvent signal is deasserted.  b)
               The OctetCount is less than 64, the
               ActivityDuration is greater than ShortEventMaxTime
               and the CollisionEvent signal is deasserted.
               ValidPacketMinTime is greater than or equal to 552
               bit times and less than 565 bit times.

               An event whose length is greater than 74 bit times
               but less than 82 bit times shall increment either
               the shortEvents counter or the runts counter but
               not both.  A CarrierEvent greater than or equal to
               552 bit times but less than 565 bit times may or
               may not be counted as a runt.

               ValidPacketMinTime has tolerances included to
               provide for circuit losses between a conformance
               test point at the AUI and the measurement point
               within the state machine.

               Runts usually indicate collision fragments, a
               normal network event.  In certain situations
               associated with large diameter networks a
               percentage of runts may exceed ValidPacketMinTime.

               The approximate minimum time for rollover of this
               counter is 16 hours."
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.6.2, aRunts."
       ::= { rptrMonitorPortEntry 9 }

   rptrMonitorPortCollisions OBJECT-TYPE
       SYNTAX    Counter
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "This counter is incremented by one for any
               CarrierEvent signal on any port for which the
               CollisionEvent signal on this port is asserted.

               The approximate minimum time for rollover of this
               counter is 16 hours."
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.6.2,
               aCollisions."
       ::= { rptrMonitorPortEntry 10 }

   rptrMonitorPortLateEvents OBJECT-TYPE
       SYNTAX    Counter
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "This counter is incremented by one for each
               CarrierEvent on this port in which the CollIn(X)
               variable transitions to the value SQE (Ref:
               9.6.6.2, IEEE 802.3 Std) while the
               ActivityDuration is greater than the
               LateEventThreshold.  Such a CarrierEvent is
               counted twice, as both a collision and as a
               lateEvent.

               The LateEventThreshold is greater than 480 bit
               times and less than 565 bit times.
               LateEventThreshold has tolerances included to
               permit an implementation to build a single
               threshold to serve as both the LateEventThreshold
               and ValidPacketMinTime threshold.

               The approximate minimum time for rollover of this
               counter is 81 hours."
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.6.2,
               aLateEvents."
       ::= { rptrMonitorPortEntry 11 }

   rptrMonitorPortVeryLongEvents OBJECT-TYPE
       SYNTAX    Counter
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "This counter is incremented by one for each
               CarrierEvent on this port whose ActivityDuration
               is greater than the MAU Jabber Lockup Protection
               timer TW3 (Ref: 9.6.1 & 9.6.5, IEEE 802.3 Std).
               Other counters may be incremented as appropriate."
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.6.2,
               aVeryLongEvents."
       ::= { rptrMonitorPortEntry 12 }

   rptrMonitorPortDataRateMismatches OBJECT-TYPE
       SYNTAX    Counter
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "This counter is incremented by one for each frame
               received on this port that meets all of the
               following conditions:  a) The CollisionEvent
               signal is not asserted.  b) The ActivityDuration
               is greater than ValidPacketMinTime.  c) The
               frequency (data rate) is detectably mismatched
               from the local transmit frequency.  The exact
               degree of mismatch is vendor specific and is to be
               defined by the vendor for conformance testing.

               When this event occurs, other counters whose
               increment conditions were satisfied may or may not
               also be incremented, at the implementor's
               discretion.  Whether or not the repeater was able
               to maintain data integrity is beyond the scope of
               this standard."
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.6.2,
               aDataRateMismatches."
       ::= { rptrMonitorPortEntry 13 }

   rptrMonitorPortAutoPartitions OBJECT-TYPE
       SYNTAX    Counter
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "This counter is incremented by one for each time
               the repeater has automatically partitioned this
               port.  The conditions that cause port partitioning
               are specified in the partition state machine in
               Section 9 [IEEE 802.3 Std].  They are not
               differentiated here."
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.6.2,
               aAutoPartitions."
       ::= { rptrMonitorPortEntry 14 }

   rptrMonitorPortTotalErrors OBJECT-TYPE
       SYNTAX    Counter
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "The total number of errors which have occurred on
               this port.  This counter is the summation of the
               values of other error counters (for the same
               port), namely:

                   rptrMonitorPortFCSErrors,
                   rptrMonitorPortAlignmentErrors,
                   rptrMonitorPortFrameTooLongs,
                   rptrMonitorPortShortEvents,
                   rptrMonitorPortLateEvents,
                   rptrMonitorPortVeryLongEvents, and
                   rptrMonitorPortDataRateMismatches.

               This counter is redundant in the sense that it is
               the summation of information already available
               through other objects.  However, it is included
               specifically because the regular retrieval of this
               object as a means of tracking the health of a port
               provides a considerable optimization of network
               management traffic over the otherwise necessary
               retrieval of the summed counters."
       ::= { rptrMonitorPortEntry 15 }


   --
   --                    The ADDRESS TRACKING GROUP
   --
   -- Implementation of this group is optional; it is appropriate
   -- for all systems which have the necessary metering.  If a
   -- managed repeater implements any part of this group, the entire
   -- group shall be implemented.

   --
   -- The Port Address Tracking Table
   --

   rptrAddrTrackTable OBJECT-TYPE
       SYNTAX    SEQUENCE OF RptrAddrTrackEntry
       ACCESS    not-accessible
       STATUS    mandatory
       DESCRIPTION
               "Table of address mapping information about the
               ports."
       ::= { rptrAddrTrackPortInfo 1 }

   rptrAddrTrackEntry OBJECT-TYPE
       SYNTAX    RptrAddrTrackEntry
       ACCESS    not-accessible
       STATUS    mandatory
       DESCRIPTION
               "An entry in the table, containing address mapping
               information about a single port."
       INDEX    { rptrAddrTrackGroupIndex, rptrAddrTrackPortIndex }
       ::= { rptrAddrTrackTable 1 }

   RptrAddrTrackEntry ::=
       SEQUENCE {
           rptrAddrTrackGroupIndex
               INTEGER,
           rptrAddrTrackPortIndex
               INTEGER,
           rptrAddrTrackLastSourceAddress
               MacAddress,
           rptrAddrTrackSourceAddrChanges
               Counter
       }

   rptrAddrTrackGroupIndex OBJECT-TYPE
       SYNTAX    INTEGER (1..1024)
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "This object identifies the group containing the
               port for which this entry contains information."
       ::= { rptrAddrTrackEntry 1 }

   rptrAddrTrackPortIndex OBJECT-TYPE
       SYNTAX    INTEGER (1..1024)
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "This object identifies the port within the group
               for which this entry contains information."
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.6.2,
               aPortID."
       ::= { rptrAddrTrackEntry 2 }

   rptrAddrTrackLastSourceAddress OBJECT-TYPE
       SYNTAX    MacAddress
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "This object is the SourceAddress of the last
               readable frame (i.e., counted by
               rptrMonitorPortReadableFrames) received by this
               port."
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.6.2,
               aLastSourceAddress."
       ::= { rptrAddrTrackEntry 3 }

   rptrAddrTrackSourceAddrChanges OBJECT-TYPE
       SYNTAX    Counter
       ACCESS    read-only
       STATUS    mandatory
       DESCRIPTION
               "This counter is incremented by one for each time
               that the rptrAddrTrackLastSourceAddress attribute
               for this port has changed.

               This may indicate whether a link is connected to a
               single DTE or another multi-user segment.
               The approximate minimum time for rollover of this
               counter is 81 hours."
       REFERENCE
               "Reference IEEE 802.3 Rptr Mgt, 19.2.6.2,
               aSourceAddressChanges."
       ::= { rptrAddrTrackEntry 4 }




--
-- D-Link common MIB v 0.1 DEFINITIONS
--     Define common MIB that can be applied on all D-Link's
--     intelligent devices


  -- device group


    dlinkDeviceName  OBJECT-TYPE
           SYNTAX    DisplayString (SIZE(0..24))
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              "  full model number of this device, e.g. DE-1500"
           ::= { device 1 }


    dlinkDeviceType  OBJECT-TYPE
           SYNTAX    INTEGER
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              "  The value indicates the type of this device.
                 The value is a sum. This value initially is zero,
                 2 raised to a power is added to the sum. The powers
                 are
                        Type        Power
                        Hub          0
                        Bridge       1
                        Router       2
                        FDDI         3
                        .........

                 for example, for the DE-2000, the value will be 3 ( 2**0+
                 2**1); for FDDI bridge, the value will be 9 (2**1+2**3)."
           ::= { device 2 }

    dlinkDeviceModel  OBJECT-TYPE
           SYNTAX    INTEGER
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              "  the model number without prefix alphabets. for example,
                 the DE-1500 Hub, the value will be 1500; the DI-1140
                 the value will be 1140"
           ::= { device 3 }

    dlinkDeviceHardwareVersion  OBJECT-TYPE
           SYNTAX    DisplayString (SIZE(0..40))
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              "  ASCII string to specify device hardware verion, e.g.
                 Rev. A1 "
           ::= { device 4 }

    dlinkDeviceSoftwareVersion  OBJECT-TYPE
           SYNTAX    INTEGER
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              " The current software/firmware version implemented in this
                device representing in non-zero integer. for example,
                the version 1.20 and 1.3 , the value will be 120 and 130,
                respectively. "
           ::= { device 5 }

    dlinkDeviceNumPorts   OBJECT-TYPE
           SYNTAX    INTEGER (0..ifNumber)
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
                " The number of outbount port in this device "
           ::= { device 6 }

    dlinkDeviceIfTable  OBJECT-TYPE
           SYNTAX    SEQUENCE OF DlinkDeviceIfEntry
           ACCESS    not-accessible
           STATUS    mandatory
           DESCRIPTION
              " The table of addressing information relevant to this
                interface corresponding to IfEntry table. The number
                of entries is given by the value of ifNumber."
           ::= { device 7 }

    dlinkDeviceifEntry  OBJECT-TYPE
           SYNTAX    DlinkDeviceIfEntry
           ACCESS    not-accessible
           STATUS    mandatory
           INDEX     { dlinkDeviceIfIndex }
           ::= { dlinkDeviceIfTable 1 }

    DlinkDeviceifEntry  ::=
          SEQUENCE {
                dlinkDeviceIfIndex
                     INTEGER,
                dlinkDeviceIfNetAddress
                     IpAddress,
                dlinkDeviceIfNetMask
                     IpAddress,
                dlinkDeviceIfDGateway
                     IpAddress,
                dlinkDeviceIfHWAddress
                     OCTET STRING
          }

    dlinkDeviceIfIndex  OBJECT-TYPE
           SYNTAX    INTEGER (1..ifNumber)
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              " The index value which uniquely identifies the interface
                to which this entry is applicable. The interface identified
                by this index is the same interface as identified by the
                same value of ifIndex."
           ::= { dlinkDeviceifEntry 1 }

    dlinkDeviceIfNetAddress  OBJECT-TYPE
           SYNTAX    IpAddress
           ACCESS    read-write
           STATUS    mandatory
           DESCRIPTION
              " The internet address of the specific interface of the
                device."
           ::= { dlinkDeviceifEntry 2 }

    dlinkDeviceIfNetMask  OBJECT-TYPE
           SYNTAX    IpAddress
           ACCESS    read-write
           STATUS    mandatory
           DESCRIPTION
              " The internet address subnet mask of the specific interface
                of the device."
           ::= { dlinkDeviceifEntry 3 }

    dlinkDeviceIfDGateway  OBJECT-TYPE
           SYNTAX    IpAddress
           ACCESS    read-write
           STATUS    mandatory
           DESCRIPTION
              " The default gateway address which the routed packets are
                delivered to."
           ::= { dlinkDeviceifEntry 4 }

    dlinkDeviceIfHWAddress  OBJECT-TYPE
           SYNTAX    OCTET STRING ( SIZE(6))
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              " The hardware address of the specific interface of the
                device."
           ::= { dlinkDeviceifEntry 5 }


 --  management group
 --

    dlinkMgtSNMPVersion   OBJECT-TYPE
           SYNTAX    INTEGER
           ACCESS    read-only
           STATUS    mandatory
           ::= { management 1 }

    dlinkMgtMIBVersion   OBJECT-TYPE
           SYNTAX    INTEGER
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              " The current version for D-Link common mib this device supportes.
                Currently, the value is 100 indicating version 1.00."
           ::= { management 2 }

    dlinkMgtSubnetControl   OBJECT-TYPE
           SYNTAX    INTEGER {
                       enable(1),
                       disable(2)
                     }
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              "  The entity indicates whether the firmware of the device
                 implements internet subnet addressing."
           ::= { management 3 }

    dlinkMgtEnableSecurity  OBJECT-TYPE
           SYNTAX    INTEGER {
                        enable(1),
                        disable(2)
                     }
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              " If the entity is enabled, the device can not be accessed
                via SNMP protocol, before user enters the login name
                (dlinkMgtLoginName) and correct password. This security
                feature is in effect only when this entity can be changed
                via console program, such as Telnet, VT100, or proprietary
                configuration software."
           ::= { management 4 }

    dlinkMgtLoginName  OBJECT-TYPE
           SYNTAX    OCTET STRING( SIZE(0..128))
           ACCESS    read-only
           STATUS    mandatory
           ::= { management 5 }

    dlinkMgtSNMPTrapAuth  OBJECT-TYPE
           SYNTAX    INTEGER  {
                     enable(1),
                     disable(2),
                     debug-mode(3)
                     }
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              " When the value is disabled, the device will not perform
                SNMP Trap report; while the value is enable the device
                should report well-defined traps. while value is debug-mode
                the device will report not only well-defined traps but the
                trap message for debugging usage."
           ::= { management 6 }

    dlinkMgtTrapLevel  OBJECT-TYPE
           SYNTAX    INTEGER (1..7)
           ACCESS    read-write
           STATUS    mandatory
           DESCRIPTION
              " Trap reporting level for occasional event. The events are
                categorized into 7 levels based on severity. For example,
                if the value set to 3, the Trap will be send to manager while
                level 1, 2, or 3 event arises, but not for level 4-7 event."
           ::= { management 7 }

    dlinkMgtTrapReportNumber OBJECT-TYPE
           SYNTAX    INTEGER
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              " The specific number of the latest trap event"
           ::= { management 8 }

    dlinkMgtTrapReportLevel  OBJECT-TYPE
           SYNTAX    INTEGER
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              " The trap level of the latest trap event"
           ::= { management 9 }

    dlinkMgtTrapReportString  OBJECT-TYPE
           SYNTAX    DisplayString (SIZE(0..127))
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              " The trap message to describe the latest trap event."
           ::= { management 10 }

    dlinkMgtTrapReportTimestamp  OBJECT-TYPE
           SYNTAX    TimeTicks
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              " the value of sysUpTime at the time the latest trap event
                arises."
           ::= { management 11 }

    dlinkMgtTrapReportPortNumber  OBJECT-TYPE
           SYNTAX    INTEGER
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              " the port number binding with this event"
           ::= { management 12 }

    dlinkMgtStationAddrTable  OBJECT-TYPE
           SYNTAX    SEQUENCE OF DlinkMgtStationAddrEntry
           ACCESS    not-accessible
           STATUS    mandatory
           DESCRIPTION
              " A table of IP address of those management stations to which
                the device will report traps."
           ::= { management 13 }

    dlinkMgtStationAddrEntry  OBJECT-TYPE
           SYNTAX    DlinkMgtStationAddrEntry
           ACCESS    not-accessible
           STATUS    mandatory
           INDEX     { dlinkMgtAddrIndex }
           ::= { dlinkMgtStationAddrTable 1 }

    DlinkMgtStationAddrEntry  ::=
          SEQUENCE {
                dlinkMgtAddrIndex
                   INTEGER,
                dlinkMgtAddrIpAddress
                   IpAddress,
                dlinkMgtAddrPhysAddress
                   OCTET STRING,
                dlinkMgtAddrAttribute
                   INTEGER,
                dlinkMgtAddrProtocol
                   INTEGER,
                dlinkMgtTrapComm
                   OCTET STRING
          }

    dlinkMgtAddrIndex  OBJECT-TYPE
           SYNTAX    INTEGER
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              " the index for entries in the Station table"
           ::= { dlinkMgtStationAddrEntry 1 }

    dlinkMgtAddrIpAddress  OBJECT-TYPE
           SYNTAX    IpAddress
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              " The IP address of the management station"
           ::= { dlinkMgtStationAddrEntry 2 }

    dlinkMgtAddrPhysAddress  OBJECT-TYPE
           SYNTAX    OCTET STRING (SIZE(6))
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              " the physical address of the management station associated
                with IP address dlinkMgtAddrIpAddress."
           ::= { dlinkMgtStationAddrEntry 3 }

    dlinkMgtAddrAttribute  OBJECT-TYPE
           SYNTAX    INTEGER {
                        dynamic(1),
                        permanent(2),
                        other(3)
                     }
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              "  the dynamic attribute relevant to the station address
                 indicates the address is learned from the network,
                 while the permanent entries is specified by user."
           ::= { dlinkMgtStationAddrEntry 4 }

    dlinkMgtProtocol  OBJECT-TYPE
           SYNTAX    INTEGER {
                        snmp-ip (1),
                        snmp-ipx (2),
                        smt (3)
                     }
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              "  indicate the frame format used in the management station"
           ::= { dlinkMgtStationAddrEntry 5 }

    dlinkMgtTrapComm  OBJECT-TYPE
           SYNTAX    DisplayString (SIZE(0..11))
           ACCESS    read-write
           STATUS    mandatory
           DESCRIPTION
              "  community name used for sending the trap to this management
                 station"
           ::= { dlinkMgtStationAddrEntry 6 }


    dlinkMgtSpecificOIDTable  OBJECT-TYPE
           SYNTAX    SEQUENCE OF DlinkMgtSpecificOIDEntry
           ACCESS    not-accessible
           STATUS    mandatory
           DESCRIPTION
              " a list of SNMP MIB groups that the device supports"
           ::= { management 14 }

    dlinkMgtSpecificOIDEntry  OBJECT-TYPE
           SYNTAX    DlinkMgtSpecificOIDEntry
           ACCESS    not-accessible
           STATUS    mandatory
           INDEX     { dlinkMgtSpecOIDIndex }
           ::= { dlinkMgtSpecificOIDTable 1 }

    DlinkMgtSpecificOIDEntry  ::=
          SEQUENCE {
                dlinkMgtSpecOIDIndex
                   INTEGER,
                dlinkMgtSpecOIDPtr
                   OBJECT IDENTIFIER,
                dlinkMgtSpecODIDescr
                   DisplayString,
                dlinkMgtSpecODIVersion
                   INTEGER
          }

    dlinkMgtSpecOIDIndex  OBJECT-TYPE
           SYNTAX    INTEGER
           ACCESS    read-only
           STATUS    mandatory
           ::= { dlinkMgtSpecificOIDEntry 1 }

    dlinkMgtSpecOIDPtr  OBJECT-TYPE
           SYNTAX    OBJECT IDENTIFIER
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              " the Object ID for the SMI enterprises subtree that
                the device did implement."
           ::= { dlinkMgtSpecificOIDEntry 2 }

    dlinkMgtSpecOIDDescr  OBJECT-TYPE
           SYNTAX    DisplayString(SIZE(1..128))
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              " the description for this MIB group"
           ::= { dlinkMgtSpecificOIDEntry 3 }

    dlinkMgtSpecOIDVersion  OBJECT-TYPE
           SYNTAX    INTEGER
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              " the version of this MIB group"
           ::= { dlinkMgtSpecificOIDEntry 4 }

    dlinkSNMPAccessTable  OBJECT-TYPE
           SYNTAX    SEQUENCE OF DlinkSNMPAccessEntry
           ACCESS    not-accessible
           STATUS    mandatory
           DESCRIPTION
              " a table of SNMP access authication"
           ::= { management 15 }

    dlinkSNMPAccessEntry  OBJECT-TYPE
           SYNTAX    DlinkSNMPAccessEntry
           ACCESS    not-accessible
           STATUS    mandatory
           INDEX     { dlinkSNMPAccessIndex }
           ::= { dlinkSNMPAccessTable 1 }

    DlinkSNMPAccessEntry  ::=
          SEQUENCE {
                dlinkSNMPAccessIndex
                   INTEGER,
                dlinkSNMPAccessCommunity
                   DisplayString,
                dlinkSNMPAccessMode
                   INTEGER
          }

    dlinkSNMPAccessIndex  OBJECT-TYPE
           SYNTAX    INTEGER
           ACCESS    read-only
           STATUS    mandatory
           ::= { dlinkSNMPAccessEntry 1 }

    dlinkSNMPAccessCommunity  OBJECT-TYPE
           SYNTAX    DisplayString(SIZE(0..11))
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
           "  the SNMP community name that allow to process SNMP entity"
           ::= { dlinkSNMPAccessEntry 2 }

    dlinkSNMPAccessMode  OBJECT-TYPE
           SYNTAX    INTEGER   {
                     get-only (1),
                     get-set (2)
                     }
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
           " the allowed access mode associated with the community name"
           ::= { dlinkSNMPAccessEntry 3 }


  --
  -- Action  group
  --

    dlinkActResetDevice  OBJECT-TYPE
           SYNTAX    INTEGER {
                        reset (1),
                        non-reset(2)
                     }
           ACCESS    read-write
           STATUS    mandatory
           DESCRIPTION
              " request system to perform reset in a few seconds"
           ::= { action 1 }

    dlinkActFactoryReset  OBJECT-TYPE
           SYNTAX    INTEGER {
                        reset (1),
                        non-reset(2)
                     }
           ACCESS    read-write
           STATUS    mandatory
           DESCRIPTION
              " Request system to perform factory reset in a few seconds,
                The system will restore the default setting in response
                to the action."
           ::= { action 2 }

    dlinkActTest  OBJECT-TYPE
           SYNTAX    INTEGER {
                        do-test (1),
                        no-test(2)
                     }
           ACCESS    read-write
           STATUS    mandatory
           DESCRIPTION
              " request system to perform internal test that don't need
                not shutdown or reset system."
           ::= { action 3 }

    dlinkActTestResult  OBJECT-TYPE
           SYNTAX    INTEGER
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              " the test result conrresponds to test (dlinkActTest)"
           ::= { action 4 }

    dlinkActPOSTResult  OBJECT-TYPE
           SYNTAX    INTEGER
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              " Power on selftest result"
           ::= { action 5 }

    dlinkActPOSTLog  OBJECT-TYPE
           SYNTAX    DisplayString (SIZE(1..128))
           ACCESS    read-only
           STATUS    mandatory
           DESCRIPTION
              " message for result of power on selftest"
           ::= { action 6 }





--
-- DE-1608 BackBone MIB Ver 1.00 DEFINITIONS
--


hubBasicPackage
         OBJECT IDENTIFIER ::= {ver-One 1}
hubMonitorPackage
         OBJECT IDENTIFIER ::= {ver-One 2}
hubAddrTrackPackage
         OBJECT IDENTIFIER ::= {ver-One 3}


hubbasicHubInfo
         OBJECT IDENTIFIER ::= {hubBasicPackage 1}
hubbasicGroupInfo
         OBJECT IDENTIFIER ::= {hubBasicPackage 2}
hubbasicPortInfo
         OBJECT IDENTIFIER ::= {hubBasicPackage 3}
hubbasicModuleInfo
         OBJECT IDENTIFIER ::= {hubBasicPackage 4}
hubbasicRedundantLinkInfo
         OBJECT IDENTIFIER ::= {hubBasicPackage 5}
hubbasicThresholdInfo
         OBJECT IDENTIFIER ::= {hubBasicPackage 6}



hubmonHubInfo
         OBJECT IDENTIFIER ::= {hubMonitorPackage 1}
hubmonGroupInfo
         OBJECT IDENTIFIER ::= {hubMonitorPackage 2}
hubmobPortInfo
         OBJECT IDENTIFIER ::= {hubMonitorPackage 3}


hubaddrtrackHubInfo
         OBJECT IDENTIFIER ::= {hubAddrTrackPackage 1}
hubaddrtrackGroupInfo
         OBJECT IDENTIFIER ::= {hubAddrTrackPackage 2}
hubaddrtrackPortInfo
         OBJECT IDENTIFIER ::= {hubAddrTrackPackage 3}



-- The HUB BASIC Package   1.3.6.1.4.1.171.7.2.1.1
-- Basic Hub Information   1.3.6.1.4.1.171.7.2.1.1.1

basicHubNumofPorts   OBJECT-TYPE
     SYNTAX    INTEGER
     ACCESS    read-only
     STATUS    mandatory
     --
     -- DESCRIPTION
     --    "DE-1608 can service PORT number. "
     --
     ::= {hubbasicHubInfo 1}

basicHubClearStats   OBJECT-TYPE
     SYNTAX    INTEGER {
                   noClearStats(1),   -- do nothing
                   clearStats(2)      -- clear
               }
     ACCESS    read-write
     STATUS    mandatory
     --
     -- DESCRIPTION
     --    "if this object set to "2", the value of
     --     objects
     --         rptrMonitorTransmitCollisions,
     --         monHubReadableFrames,
     --         monHubReadableOctets,
     --     and monHubTotalErrors will reset to zero."
     --
     ::= {hubbasicHubInfo 2}



-- The HUB BASIC Package   1.3.6.1.4.1.171.7.2.1.1
-- Basic Group Information 1.3.6.1.4.1.171.7.2.1.1.2

basicGroupTable   OBJECT-TYPE
     SYNTAX    SEQUENCE OF BasicGroupEntry
     ACCESS    not-accessible
     STATUS    mandatory
     -- DESCRIPTION
     --    "Table of descriptive and status information about
     --    the groups of ports."
     --
     ::= {hubbasicGroupInfo 1}

basicGroupEntry   OBJECT-TYPE
     SYNTAX    BasicGroupEntry
     ACCESS    not-accessible
     STATUS    mandatory
     -- DESCRIPTION
     --
     --    "An entry in the table, containing information
     --    about a single group of ports."
     --
     INDEX {basicGroupIndex }
     ::= {basicGroupTable 1}

BasicGroupEntry ::=
     SEQUENCE  {
         basicGroupIndex
              INTEGER,
         basicGroupName
              DisplayString,
         basicGroupClearStats
              INTEGER,
         basicGroupLed
              OCTET STRING,
     }

basicGroupIndex    OBJECT-TYPE
     SYNTAX    INTEGER
     ACCESS    read-only
     STATUS    mandatory
     -- DESCRIPTION
     --
     --    "This object identifies the group within the
     --     HUB for which this entry contains information."
     --
     ::= {basicGroupEntry 1 }

basicGroupName     OBJECT-TYPE
     SYNTAX    DisplayString ( SIZE(0..20))
     ACCESS    read-write
     STATUS    mandatory
     ::= {basicGroupEntry 2 }

basicGroupClearStats    OBJECT-TYPE
     SYNTAX    INTEGER {
                   noGroupClearStats(1),   -- do nothing
                   groupClearStats(2)      -- clear
               }
     ACCESS    read-write
     STATUS    mandatory
     -- DESCRIPTION
     --
     --    "if this object set to "2", the value of
     --    objects
     --        rptrMonitorGroupTotalFrames,
     --        rptrMonitorGroupTotalOctets,
     --        rptrMonitorGroupTotalErrors,
     --    and monGroupCollisions will reset to zero."
     --
     --REFERENCE
     --
     --    "About the object
     --         rptrMonitorGroupTotalFrames,
     --         rptrMonitorGroupTotalOctets,
     --     and rptrMonitorGroupTotalErrors, please refer to
     --     RFC 1368."
     --
     ::= {basicGroupEntry 3 }

basicGroupLed   OBJECT-TYPE
     SYNTAX  OCTET STRING ( SIZE(20) )
            -- {
            --     struct {
            --         u_char autopart{
            --               partition(1),
            --               no partition(2)
            --         };
            --         u_char portstate{
            --               port enable(1),
            --               port disable(2)
            --         };
            --
            --     } PORTLED[10];
            -- }
     ACCESS  read-only
     STATUS  mandatory
     ::= {basicGroupEntry 4 }



-- The HUB BASIC Package   1.3.6.1.4.1.171.7.2.1.1
-- Basic Port Information  1.3.6.1.4.1.171.7.2.1.1.3

basicPortTable    OBJECT-TYPE
     SYNTAX    SEQUENCE OF BasicPortEntry
     ACCESS    not-accessible
     STATUS    mandatory
     -- DESCRIPTION
     --    "Table of descriptive and status information about
     --    the groups of ports."
     --
     ::= {hubbasicPortInfo  1}

basicPortEntry    OBJECT-TYPE
     SYNTAX    BasicPortEntry
     ACCESS    not-accessible
     STATUS    mandatory
     -- DESCRIPTION
     --    "An entry in the table, containing information
     --    about a single port."
     --
     INDEX    { basicPortGroupIndex, basicPortIndex }
     ::= {basicPortTable  1}

BasicPortEntry ::=
     SEQUENCE  {
         basicPortGroupIndex
             INTEGER,
         basicPortIndex
             INTEGER,
         basicPortName
             DisplayString,
         basicPortType
             INTEGER,
         basicPortLink
             INTEGER,
         basicPortClearStats
             INTEGER,
     }

basicPortGroupIndex   OBJECT-TYPE
     SYNTAX    INTEGER
     ACCESS    read-only
     STATUS    mandatory
     -- DESCRIPTION
     --    "This object identifies the group containing the
     --    port for which this entry contains information."
     --
     ::= {basicPortEntry  1}

basicPortIndex   OBJECT-TYPE
     SYNTAX    INTEGER
     ACCESS    read-only
     STATUS    mandatory
     -- DESCRIPTION
     --     "This object identifies the port within the group
     --     for which this entry contains information."
     --
     ::= {basicPortEntry  2}

basicPortName    OBJECT-TYPE
     SYNTAX    DisplayString( SIZE(0..12))
     ACCESS    read-write
     STATUS    mandatory
     ::= {basicPortEntry  3}

basicPortType    OBJECT-TYPE
     SYNTAX  INTEGER {
                 other(1),
                 noconnected(2),
                 tenBaseT(3),
                 tenBase2(4),
                 tenBase5(5),
                 fOEIL(6)
             }
     ACCESS  read-only
     STATUS  mandatory
     ::= {basicPortEntry  4}

basicPortLink    OBJECT-TYPE
     SYNTAX  INTEGER {
                 up(1),
                 down(2)
             }
     ACCESS  read-only
     STATUS  mandatory
     ::= {basicPortEntry  5}

basicPortClearStats   OBJECT-TYPE
     SYNTAX  INTEGER {
                 noPortClearStats(1),   -- do nothing
                 portClearStats(2)      -- clear
             }
     ACCESS  read-write
     STATUS  mandatory
     -- DESCRIPTION
     --
     --    "if this object set to "2", the value of
     --    same port objects
     --        rptrMonitorPortReadableFrames,
     --        rptrMonitorPortReadableOctets,
     --        rptrMonitorPortFCSErrors,
     --        rptrMonitorPortAlignmentErrors,
     --        rptrMonitorPortFrameTooLongs,
     --        rptrMonitorPortShortEvents,
     --        rptrMonitorPortRunts,
     --        rptrMonitorPortCollisions,
     --        rptrMonitorPortLateEvents,
     --        rptrMonitorPortVeryLongEvents,
     --        rptrMonitorPortDataRateMismatches,
     --        rptrMonitorPortAutoPartitions,
     --    and rptrMonitorPortTotalErrors  will reset to zero."
     --
     ::= {basicPortEntry  6}



-- The HUB BASIC Package   1.3.6.1.4.1.171.7.2.1.1
-- Basic Group Information 1.3.6.1.4.1.171.7.2.1.1.4

basicModuleTable   OBJECT-TYPE
     SYNTAX    SEQUENCE OF BasicGroupEntry
     ACCESS    not-accessible
     STATUS    mandatory
     -- DESCRIPTION
     --    "Table of descriptive and status information about
     --    the groups of ports."
     --
     ::= {hubbasicModuleInfo 1}

basicModuleEntry   OBJECT-TYPE
     SYNTAX    BasicModuleEntry
     ACCESS    not-accessible
     STATUS    mandatory
     -- DESCRIPTION
     --
     --    "An entry in the table, containing information
     --    about a single group of ports."
     --
     INDEX {basicModuleIndex }
     ::= {basicModuleTable 1}

BasicModuleEntry ::=
     SEQUENCE  {
         basicModuleIndex
              INTEGER,
         basicModuleType
              INTEGER,
     }

basicModuleIndex    OBJECT-TYPE
     SYNTAX    INTEGER
     ACCESS    read-only
     STATUS    mandatory
     -- DESCRIPTION
     --
     --    "This object identifies the module within the
     --     HUB for which this entry contains information."
     --
     ::= {basicModuleEntry 1 }

basicModuleType     OBJECT-TYPE
     SYNTAX    INTEGER {
                   unknown(1),
                   noconnected(2),
                   tenBaseT(3),
                   tenBase2(4),
                   tenBase5(5),
                   FORIL(6)
               }
     ACCESS    read-only
     STATUS    mandatory
     ::= {basicModuleEntry 2 }


--------------------------------------------------------------------

-- The HUB BASIC Package              1.3.6.1.4.1.171.7.2.1.1
-- Basic Redundant Link Information   1.3.6.1.4.1.171.7.2.1.1.5

basicRedundantLinkfunction   OBJECT-TYPE
     SYNTAX  INTEGER {
                 supportRedundantLinkfunction(1),
                 noSupportRedundantLinkfunction(2)
             }
     ACCESS  read-only
     STATUS  mandatory
     ::= {hubbasicRedundantLinkInfo 1}

basicRedundantLink   OBJECT-TYPE
     SYNTAX  INTEGER {
                 hubRedundantLinkenable(1),
                 nohubRedundantLink(2)
             }
     ACCESS  read-write
     STATUS  mandatory
     ::= {hubbasicRedundantLinkInfo 2}

basicRedundantLinkClear   OBJECT-TYPE
     SYNTAX  INTEGER {
                 nohubRedundantLinkClear(1),
                 hubRedundantLinkClear(2)
             }
     ACCESS  read-write
     STATUS  mandatory
     -- DESCRIPTION
     --
     --    "If this object is set to "2", all of the
     --    hub redundant link object will clear."
     --
     ::= {hubbasicRedundantLinkInfo 3}


basicNumofRedundantLinkEntry   OBJECT-TYPE
     SYNTAX    INTEGER
     ACCESS    read-only
     STATUS    mandatory
     -- DESCRIPTION
     --
     --    "DE-1608 can service 5 RedundantLinkGrp."
     --
     ::= {hubbasicRedundantLinkInfo 4}


basicRedundantLinkTable  OBJECT-TYPE
     SYNTAX    SEQUENCE OF BasicRedundantLinkEntry
     ACCESS    not-accessible
     STATUS    mandatory
     -- DESCRIPTION
     --    "Table of descriptive information / configuration
     --     about the threshold managnment. "
     --
     ::= {hubbasicRedundantLinkInfo  5}

basicRedundantLinkEntry OBJECT-TYPE
     SYNTAX    BasicRedundantLinkEntry
     ACCESS    not-accessible
     STATUS    mandatory
     -- DESCRIPTION
     --
     --    "An entry in the table, containing information
     --    about a single redundant link group."
     --
     INDEX    {basicEThresholdIndex }
     ::= {basicRedundantLinkTable  1}

BasicRedundantLinkEntry ::=
     SEQUENCE  {
         basicRedundantLinkGrpIndex
             INTEGER,
         basicRedundantLinkPriPortno
             INTEGER,
         basicRedundantLinkSecPortno
             INTEGER,
         basicRedundantLinkEWrkPortno
             INTEGER,
         basicRedundantLinkEntryState
             INTEGER,
         basicRedundantLinkExcReasone
             INTEGER
     }

basicRedundantLinkEGrpIndex   OBJECT-TYPE
     SYNTAX    INTEGER (1..4)
     ACCESS    read-only
     STATUS    mandatory
     ::= {basicRedundantLinkEntry  1}

basicRedundantLinkEPriPortno   OBJECT-TYPE
     SYNTAX    INTEGER
     ACCESS    read-write
     STATUS    mandatory
     -- DESCRIPTION
     --
     --    "1,2  or 3,4  or 5,6  or  7,8"
     --
     ::= {basicRedundantLinkEntry  2}

basicRedundantLinkESecPortno   OBJECT-TYPE
     SYNTAX    INTEGER
     ACCESS    read-only
     STATUS    mandatory
     -- DESCRIPTION
     --
     --    "1,2  or 3,4  or 5,6  or  7,8"
     --
     ::= {basicRedundantLinkEntry  3}

basicRedundantLinkEWrkPortno  OBJECT-TYPE
     SYNTAX    INTEGER
               -- {
               --     1 or 2, if basicRedundantLinkEGrpIndex == 1.
               --     3 or 4, if basicRedundantLinkEGrpIndex == 1.
               --     5 or 6, if basicRedundantLinkEGrpIndex == 1.
               --     7 or 8, if basicRedundantLinkEGrpIndex == 1.
               -- }
     ACCESS    read-only
     STATUS    mandatory
     -- DESCRIPTION
     --
     --    This Object is used to describe the working port on the
     --    corresponding redundant link pair.
     --
     ::= {basicRedundantLinkEntry  4}

basicRedundantLinkEntryState
     SYNTAX    INTEGER {
                   On(1),   -- Enable Module Redundant link function.
                   OFF(2)
               }
     ACCESS    read-write
     STATUS    mandatory
     ::= {basicRedundantLinkEntry  5}


basicRedundantLinkExcReasone   OBJECT-TYPE
     SYNTAX    INTEGER {
                   unknown(1),
                   manual_select_primary_port(2),
                   manual_select_secondary_port(3),
                   primary_port_partitioned(4),
                   secondary_port_partitioned(5),
                   primary_port_linked_dwn(6),
                   secondary_port_linked_dwn(7)
               }
     ACCESS    read-only
     STATUS    mandatory
     ::= {basicRedundantLinkEntry  6}

--------------------------------------------------------------------


-- The HUB BASIC Package         1.3.6.1.4.1.171.7.2.1.1
-- Basic Threshold Information   1.3.6.1.4.1.171.7.2.1.1.6

basicThresholdfunction  OBJECT-TYPE
     SYNTAX  INTEGER {
                 supportThresholdfunction(1),
                 noSupportThresholdfunction(2)
             }
     ACCESS  read-only
     STATUS  mandatory
     ::= {hubbasicThresholdInfo 1}

basicThreshold   OBJECT-TYPE
     SYNTAX  INTEGER {
                 hubThresholdenable(1),
                 nohubThreshold(2)
             }
     ACCESS  read-write
     STATUS  mandatory
     ::= {hubbasicThresholdInfo 2}

basicThresholdClear   OBJECT-TYPE
     SYNTAX  INTEGER {
                 nohubThresholdClear(1),
                 hubThresholdclear(2)
             }
     ACCESS  read-write
     STATUS  mandatory
     -- DESCRIPTION
     --
     --    "If this object is set to "2", all of the
     --    hub threshold object will clear."
     --
     ::= {hubbasicThresholdInfo 3}

basicNumofThresholdEntry   OBJECT-TYPE
     SYNTAX    INTEGER
     ACCESS    read-only
     STATUS    mandatory
     -- DESCRIPTION
     --
     --    "DE-1600 can service 10 Threshold Entries."
     --
     ::= {hubbasicThresholdInfo 4}

basicEThresholdTable   OBJECT-TYPE
     SYNTAX    SEQUENCE OF BasicEThresholdEntry
     ACCESS    not-accessible
     STATUS    mandatory
     -- DESCRIPTION
     --    "Table of descriptive information / configuration
     --     about the threshold managnment. "
     --
     ::= {hubbasicThresholdInfo 5}

basicEThresholdEntry   OBJECT-TYPE
     SYNTAX    BasicEThresholdEntry
     ACCESS    not-accessible
     STATUS    mandatory
     -- DESCRIPTION
     --
     --    "An entry in the table, containing information
     --    about a single threshold."
     --
     INDEX    {basicEThresholdIndex }
     ::= {basicEThresholdTable 1}

BasicEThresholdEntry  ::=
     SEQUENCE  {
         basicEThresholdIndex
             INTEGER,
         basicEThresholdClass
             INTEGER,
         basicEThresholdMode
             INTEGER,
         basicEThresholdGroup
             INTEGER,
         basicEThresholdPort
             INTEGER,
         basicEThresholdType
             INTEGER,
         basicEThresholdUBound
             INTEGER,
         basicEThresholdLBound
             INTEGER,
         basicEThresholdCounter
             INTEGER,
         basicEThresholdState
             INTEGER,
         basicEThresholdClear
             INTEGER,
         basicEThresholdAction
             INTEGER
     }

basicEThresholdIndex   OBJECT-TYPE
     SYNTAX    INTEGER
     ACCESS    read-only
     STATUS    mandatory
     ::= {basicEThresholdEntry  1}

basicEThresholdClass  OBJECT-TYPE
     SYNTAX    INTEGER {
                   unknown(1),
                   accumulate(2),
                   rate(3)
               }
     ACCESS    read-write
     STATUS    mandatory
     -- DESCRIPTION
     --   "In Accurate Threshold Class, after the specific counter
     --    is greater than the assigned value, the corresponding
     --    trap will send from device.
     --
     --    In Rate Threashold Class, if the specific gauge rate
     --    is above the assigned value, the corresponding trap
     --    will send from device. (in a 5 secs period) "
     --
     ::= {basicEThresholdEntry  2}

basicEThresholdMode   OBJECT-TYPE
     SYNTAX    INTEGER {
                   unknown(1),
                   groupthreshold(2),
                   portthreshold(3)
               }
     ACCESS    read-write
     STATUS    mandatory
     ::= {basicEThresholdEntry  3}

basicEThresholdGroup   OBJECT-TYPE
     SYNTAX    INTEGER ( 1 .. 4)
     ACCESS    read-write
     STATUS    mandatory
     ::= {basicEThresholdEntry  4}

basicEThresholdPort   OBJECT-TYPE
     SYNTAX    INTEGER ( 1 .. 10)
     ACCESS    read-write
     STATUS    mandatory
     ::= {basicEThresholdEntry  5}

basicEThresholdType   OBJECT-TYPE
     SYNTAX    INTEGER {
                   unknown(1),
                   portReadableFrames(2),        -- /* Good Frame     */
                   portReadableOctets(3),        -- /* Good Byte      */
                   portTotalErrors(4),
                   portCollisions(5),
                   portFCSErrors(6),
                   portAlignmentErrors(7),
                   portFrameTooLongs(8),         -- /* Long Frame     */
                   portShortEvents(9),           -- /* Fragment       */
                   portRunts(10),                -- /* Short Frame    */
                   portLateEvents(11),           -- /* Late Collision */
                   portVeryLongEvents(12),       -- /* Jabber         */
                   portDataRateMismatches(13),
                   portAutoPartitions(14),

                   groupReadableFrames(21),
                   groupReadableOctets(22),
                   groupTotalErrors(23),
                   groupCollisions(24)
               }
     ACCESS    read-write
     STATUS    mandatory
     ::= {basicEThresholdEntry  6}

basicEThresholdUBound   OBJECT-TYPE
     SYNTAX    INTEGER
     ACCESS    read-write
     STATUS    mandatory
     -- DESCRIPTION
     --
     --    "In Rate Threshold Class, If the corresponding
     --     rate is greater than this object rate, the corresponding
     --     trap will send from device.  In the same period
     --     only ONE trap will send from device, although the
     --     rate is greater than this rate in the remainder period."
     --
     ::= {basicEThresholdEntry  7}

basicEThresholdLBound   OBJECT-TYPE
     SYNTAX    INTEGER
     ACCESS    read-write
     STATUS    mandatory
     -- DESCRIPTION
     --
     --    "In Rate Threshold Class, after the corresponding
     --     rate is greater than this object rate. Soon the
     --     corresponding rate is lower than this object rate.
     --     the corresponding trap will send from device.  In
     --     the same period only ONE trap will send from device,
     --     although the rate is lower than this rate in the
     --     remainder period. basicEThresholdLBound is less than
     --     basicEThresholdUBound "
     --
     ::= {basicEThresholdEntry  8}

basicEThresholdCounter   OBJECT-TYPE
     SYNTAX    INTEGER
     ACCESS    read-write
     STATUS    mandatory
     -- DESCRIPTION
     --
     --    "In Accurate Threshold Class, after the corresponding
     --     counter is greater than this object. the corresponding
     --     trap will send from device."
     --
     ::= {basicEThresholdEntry  9}

basicEThresholdState   OBJECT-TYPE
     SYNTAX  INTEGER {
                 entryThresholdenable(1),
                 noEntryThreshold(2)
             }
     ACCESS  read-write
     STATUS  mandatory
     ::= {basicEThresholdEntry  10}

basicEThresholdClear   OBJECT-TYPE
     SYNTAX  INTEGER {
                 noEntryThresholdClear(1),
                 entryThresholClear(2)
             }
     ACCESS  read-write
     STATUS  mandatory
     -- DESCRIPTION
     --    "If this object is set to "2", the value of this entry
     --     will reset to zero."
     --
     ::= {basicEThresholdEntry  11}


basicEThresholdAction   OBJECT-TYPE
     SYNTAX  INTEGER {
                 warning(1),
                 autoDisable(2),
                 warning-and-AutoDisable(3)
             }
     ACCESS  read-write
     STATUS  mandatory
     ::= {basicEThresholdEntry  12}



--------------------------------------------------------------------



-- The HUB Monitor Package   1.3.6.1.4.1.171.7.2.1.2
-- Monitor Hub Information   1.3.6.1.4.1.171.7.2.1.2.1

monHubReadableFrames   OBJECT-TYPE
     SYNTAX    INTEGER
     ACCESS    read-only
     STATUS    mandatory
     -- DESCRIPTION
     --    "sum of rptrMonitorGroupTotalFrames."
     --
     ::= {hubmonHubInfo  1}

monHubReadableOctets   OBJECT-TYPE
     SYNTAX    INTEGER
     ACCESS    read-only
     STATUS    mandatory
     -- DESCRIPTION
     --    "sum of rptrMonitorGroupTotalOctets."
     --
     ::= {hubmonHubInfo  2}

monHubTotalErrors      OBJECT-TYPE
     SYNTAX    INTEGER
     ACCESS    read-only
     STATUS    mandatory
     -- DESCRIPTION
     --    "sum of monGroupCollisions."
     --
     ::= {hubmonHubInfo  3}



-- The HUB Monitor Package   1.3.6.1.4.1.171.7.2.1.2
-- Monitor Group Information 1.3.6.1.4.1.171.7.2.1.2.2

monGroupTable    OBJECT-TYPE
     SYNTAX    SEQUENCE OF MonGroupEntry
     ACCESS    not-accessible
     STATUS    mandatory
     ::= {hubmonGroupInfo 1}

monGroupEntry    OBJECT-TYPE
     SYNTAX    MonGroupEntry
     ACCESS    not-accessible
     STATUS    mandatory
     -- DESCRIPTION
     --
     --    "An entry in the table, containing information
     --    about a single threshold."
     --
     INDEX    {monGroupIndex  }
     ::= {monGroupTable 1}

MonGroupEntry ::=
     SEQUENCE  {
         monGroupIndex
             INTEGER,
         monGroupLedFlag
             INTEGER
     }

monGroupIndex    OBJECT-TYPE
     SYNTAX    INTEGER
     ACCESS    read-only
     STATUS    mandatory
     ::= {monGroupEntry 1}

monGroupLedFlag     OBJECT-TYPE
     SYNTAX    INTEGER {
                   no-PercentageLED-ON(1),
                   upto-onePercentageLED-ON(2),
                   upto-fivePercentageLED-ON(3),
                   upto-tenPercentageLED-ON(4),
                   upto-twentyPercentageLED-ON(5),
                   upto-thirtyPercentageLED-ON(6),
                   upto-fiftyorabovePercentageLED-ON(7)
               }
     ACCESS    read-only
     STATUS    mandatory
     ::= {monGroupEntry 2}

END

-- EOF


